@@ -9,7 +9,7 @@ use Carp;
 use Config;
 use IPC::Run qw(run binary);
 
-our $VERSION = '2.19';
+our $VERSION = '2.24';
 
 =pod
 
@@ -392,7 +392,7 @@ The 'node', 'edge' and 'graph' attributes allow you to specify global
 node, edge and graph attributes (in addition to those controlled by
 the special attributes described above). The value should be a hash
 reference containing the corresponding key-value pairs. For example,
-to make all nodes box-shaped (unless explicity given another shape):
+to make all nodes box-shaped (unless explicitly given another shape):
 
   my $g = GraphViz->new(node => {shape => 'box'});
 
@@ -1367,6 +1367,15 @@ The keywords are: node, edge, graph, digraph, subgraph and strict. Compass point
 See L<keywords|http://www.graphviz.org/content/dot-language> in the discussion of the syntax of DOT
 for details.
 
+=head2 How do you handle XXE within XML?
+
+Due to security risks with XXE in XML, Graphviz does not support XML that contains XXE. Thus it
+automatically prevents external entities being parsed by using the no_xxe option in L<XML::Twig>
+when calling XML::Twig -> new(). And for this reason also the pre-reqs in Makefile.PL specify
+XML::Twig V 3.52.
+
+See L<https://metacpan.org/pod/release/MIROD/XML-Twig-3.52/Twig.pm#no_xxe>
+
 =head1 NOTES
 
 Older versions of GraphViz used a slightly different syntax for node
@@ -1382,20 +1391,26 @@ GraphViz is deprecated in favour of L<GraphViz2>.
 
 The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/GraphViz>
+
 =head1 AUTHOR
 
 Leon Brocard: E<lt>F<acme@astray.com>E<gt>.
 
 Current maintainer: Ron Savage I<E<lt>ron@savage.net.auE<gt>>.
 
+My homepage: L<http://savage.net.au/>.
+
 =head1 COPYRIGHT
 
 Copyright (C) 2000-4, Leon Brocard
 
 =head1 LICENSE
 
-This module is free software; you can redistribute it or modify it
-under the same terms as Perl itself.
+This module is free software; you can redistribute it or modify it under the Perl License,
+a copy of which is available at L<http://dev.perl.org/licenses/>.
 
 =cut
 
